<?xml version="1.0" encoding="ISO-8859-1"?>
<!-- ne pas oublier le namespace SDX -->
<xsl:stylesheet version="1.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:sdx="http://www.culture.gouv.fr/ns/sdx/sdx" 
  exclude-result-prefixes="xsl sdx">
   <!-- doit-on proposer les liens d'aide au dbogage ? -->
   <xsl:variable name="debug" select="true()"/>
	<!-- on rcupre les infos concernant l'utilisateur -->
	<xsl:variable name="user" select="/sdx:document/sdx:user"/>
	<!-- le modle pour la "racine" du contexte SDX -->
	<xsl:template match="/sdx:document">
		<!-- le squelette du document HTML -->
		<html>
			<head>
				<title>Mon application</title>
			</head>
			<body>
				<!-- la barre de menus -->
				<xsl:call-template name="menubar"/>
				<!-- les modles spcifiques  chaque XSP -->
				<xsl:apply-templates/>
				<!-- le bas de page -->
				<xsl:call-template name="footer"/>
			</body>
		</html>
	</xsl:template>
	<xsl:template name="menubar">
	   <!-- le contexte de notre application -->
	   <xsl:variable name="app_context">/mon_app/</xsl:variable>
		<!-- on rcupre le contexte SDX -->
		<!-- http://server:port/sdx par exemple -->
		<xsl:variable name="SDX_context" select="/sdx:document/@server"/>
		<!-- on rcupre l'URI de la page courante -->
		<!-- http://server:port/sdx/mon_app/index.xsp par exemple -->
		<xsl:variable name="page_URI" select="/sdx:document/@uri"/>
		<!-- on en dduit le contexte de la page dans SDX -->
		<!-- /mon_app/index.xsp par exemple -->
		<xsl:variable name="page_SDX" select="substring-after($page_URI,$SDX_context)"/>
		<!-- on en dduit le contexte de la page dans l'application -->
		<!-- index.xsp par exemple -->
		<xsl:variable name="page_name" select="substring-after($page_URI,$app_context)"/>
		<!-- 
		notre application insrera un lment <admin_page/>
		pour les pages ncessitant des privilges d'administrateur,
		s'il est detect, on est dans une telle page
		-->
		<xsl:variable name="admin_page" select="boolean(/sdx:document/admin_page)"/>
		<table align="center" cellpadding="10">
			<tr>
				<!--
				si on n'est pas dans la page d'index,
				propose un lien vers elle
				-->
				<xsl:if test="not($page_name = 'index.xsp')">
					<td>
						<a href="index.xsp">Index</a>
					</td>
				</xsl:if>
				<!-- 
				si on n'est pas dans la page d'interrogation,
				propose un lien vers elle
				 -->
				<xsl:if test="not($page_name = 'query.xsp')">
					<td>
						<a href="query.xsp">Interrogation</a>	
					</td>
				</xsl:if>
				<!--
				si on n'est pas dans la page d'identification,
				propose un lien vers elle
				 -->
				<xsl:if test="not($page_name = 'login.xsp')">
					<td>
						<a href="login.xsp">Identification</a>
					</td>
				</xsl:if>
				<!--
				si on est identifi hors d'une page d'administration,
				propose une dconnection : on reste sur la mme page
				 -->
				<xsl:if test="not($admin_page) and not($user/@anonymous)">
					<td>
						<!-- 
						truc SDX : 
						il suffit de passer un paramtre logout non vide 
						-->
						<a href="{$page_URI}?logout=yes">Fin d'identification</a>
					</td>
				</xsl:if>
				<!-- 
				si on n'est pas sur la page d'ajout de documents
				et si on est administrateur,
				propose un lien vers elle
				-->
				<xsl:if test="not($page_name = 'query.xsp') and $user/@admin='true'">
					<td>
						<a href="upload.xsp">Ajouter des documents</a>
					</td>
				</xsl:if>
			</tr>
		</table>
		<hr/>
		<br/>
	</xsl:template>
	<xsl:template name="footer">
		<br/>
		<hr/>
		<xsl:call-template name="userinfo"/>
		<xsl:if test="$debug">
			<xsl:call-template name="views"/>
		</xsl:if>
	</xsl:template>
	<xsl:template name="userinfo">
		<!-- rien  faire si l'utilisateur est anonyme -->
		<xsl:if test="not($user/@anonymous)">
			<!-- on reconstitue le nom de l'utilisateur -->
			<xsl:variable name="fullname">
				<xsl:if test="$user/@firstname or $user/@lastname">
					(
					<xsl:if test="$user/@firstname">
						<xsl:value-of select="$user/@firstname"/>&#160;
					</xsl:if>
					<xsl:if test="$user/@lastname">
						<xsl:value-of select="$user/@lastname"/>&#160;
					</xsl:if>
					),
				</xsl:if>
			</xsl:variable>
			<!-- on dtermine son statut -->
			<xsl:variable name="user_status">
				<xsl:choose>
					<xsl:when test="$user/@superuser='true'">
						le super-utilisateur
					</xsl:when>
					<xsl:when test="$user/@admin='true'">
						un administrateur
					</xsl:when>
					<xsl:when test="$user/@app">
						un utilisateur
					</xsl:when>
					<!-- au cas o on aurait oubli quelque chose... -->
					<xsl:otherwise>bug !</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
			<!-- et on sort l'info -->
			<div class="user">	
				Vous <xsl:value-of select="$fullname"/> tes identifi sous le code 
				<span class="user_id"><xsl:value-of select="$user/@id"/></span>. 
				Vous tes <xsl:value-of select="$user_status"/> de l'application&#160;
				<span class="app_id"><xsl:value-of select="$application"/></span>.
			</div>
		</xsl:if>
	</xsl:template>
	<xsl:template name="views">
		<table>
			<tr>
				<td>Les tapes de cette page : </td>
				<td>1) <a href="{/sdx:document/@uri}2xsp{/sdx:document/@query}">XSP</a>
				</td>
				<td>2) <a href="{/sdx:document/@uri}2sdx{/sdx:document/@query}">SDX</a>
				</td>
				<td>3) <a href="{/sdx:document/@uri}2htm{/sdx:document/@query}">HTM</a>
				</td>
			</tr>
		</table>
	</xsl:template>
	<!-- 
	un template qu'on pourra utiliser
	si un utilisateur cherche  faire des oprations
	pour lesquelles il n'a pas les privilges suffisants
	-->
	<xsl:template match="nosuchprivileges">
		<div class="privileges">
		Vous n'avez pas les privilges suffisants pour effectuer cette opration.
		</div>
	</xsl:template>
</xsl:stylesheet>